@@ -1,4 +1,4 @@
-/* Copyright 2010 by Roger S. Bivand. */
+/* Copyright 2010-24 by Roger S. Bivand. */
 
 #include "spatialreg.h"
 
@@ -46,7 +46,7 @@ SEXP opt_error_init(void) { /* -Wstrict-prototypes */
     OPT_ERROR_SSE *pt;
     SEXP ptr;
 
-    pt = Calloc(1, OPT_ERROR_SSE);
+    pt = R_Calloc(1, OPT_ERROR_SSE);
     pt->set = FALSE;
 
     PROTECT(ptr = R_MakeExternalPtr(pt, R_NilValue, R_NilValue));
@@ -63,31 +63,31 @@ void opt_error_set(SEXP env) {
     SEXP y, x, wy, WX;
     int i, n, p, np, pc=0;
 
-    n = INTEGER_POINTER(findVarInFrame(env, install("n")))[0];
-    p = INTEGER_POINTER(findVarInFrame(env, install("p")))[0];
+    n = INTEGER_POINTER(Rf_findVarInFrame(env, Rf_install("n")))[0];
+    p = INTEGER_POINTER(Rf_findVarInFrame(env, Rf_install("p")))[0];
     np = n*p;
 
-    pt = (OPT_ERROR_SSE *) R_ExternalPtrAddr(findVarInFrame(env,
-        install("ptr")));
-    if (pt->set) error("opt_error_set: function called out of order");
+    pt = (OPT_ERROR_SSE *) R_ExternalPtrAddr(Rf_findVarInFrame(env,
+        Rf_install("ptr")));
+    if (pt->set) Rf_error("opt_error_set: function called out of order");
 
-    PROTECT(y = findVarInFrame(env, install("y"))); pc++;
-    PROTECT(x = findVarInFrame(env, install("x"))); pc++;
-    PROTECT(wy = findVarInFrame(env, install("wy"))); pc++;
-    PROTECT(WX = findVarInFrame(env, install("WX"))); pc++;
+    PROTECT(y = Rf_findVarInFrame(env, Rf_install("y"))); pc++;
+    PROTECT(x = Rf_findVarInFrame(env, Rf_install("x"))); pc++;
+    PROTECT(wy = Rf_findVarInFrame(env, Rf_install("wy"))); pc++;
+    PROTECT(WX = Rf_findVarInFrame(env, Rf_install("WX"))); pc++;
 
-    pt->y = Calloc(n, double);
-    pt->x = Calloc(np, double);
-    pt->yl = Calloc(n, double);
-    pt->wy1 = Calloc(n, double);
-    pt->xlq = Calloc(np, double);
-    pt->wx1 = Calloc(np, double);
-    pt->qy = Calloc(np, double);
-    pt->xlqyl = Calloc(p, double);
-    pt->jpvt = Calloc(p, int);
-    pt->work = Calloc(p*2, double); 
-/*    pt->work = Calloc(p, double); */
-    pt->qraux = Calloc(p, double);
+    pt->y = R_Calloc(n, double);
+    pt->x = R_Calloc(np, double);
+    pt->yl = R_Calloc(n, double);
+    pt->wy1 = R_Calloc(n, double);
+    pt->xlq = R_Calloc(np, double);
+    pt->wx1 = R_Calloc(np, double);
+    pt->qy = R_Calloc(np, double);
+    pt->xlqyl = R_Calloc(p, double);
+    pt->jpvt = R_Calloc(p, int);
+    pt->work = R_Calloc(p*2, double); 
+/*    pt->work = R_Calloc(p, double); */
+    pt->qraux = R_Calloc(p, double);
 
     for (i=0; i<n; i++) {
         pt->y[i] = NUMERIC_POINTER(y)[i];
@@ -110,19 +110,19 @@ SEXP opt_error_free(SEXP ptr) {
 
     pt = (OPT_ERROR_SSE *) R_ExternalPtrAddr(ptr);
 
-    Free(pt->qraux);
-    Free(pt->work);
-    Free(pt->jpvt);
-    Free(pt->xlqyl);
-    Free(pt->qy);
-    Free(pt->wx1);
-    Free(pt->xlq);
-    Free(pt->wy1);
-    Free(pt->yl);
-    Free(pt->x);
-    Free(pt->y);
+    R_Free(pt->qraux);
+    R_Free(pt->work);
+    R_Free(pt->jpvt);
+    R_Free(pt->xlqyl);
+    R_Free(pt->qy);
+    R_Free(pt->wx1);
+    R_Free(pt->xlq);
+    R_Free(pt->wy1);
+    R_Free(pt->yl);
+    R_Free(pt->x);
+    R_Free(pt->y);
 
-    Free(pt);
+    R_Free(pt);
     R_ClearExternalPtr(ptr);
     return(R_NilValue);
 }
@@ -132,7 +132,7 @@ SEXP hess_error_init(void) { /* -Wstrict-prototypes */
     HESS_ERROR_SSE *pt;
     SEXP ptr;
 
-    pt = Calloc(1, HESS_ERROR_SSE);
+    pt = R_Calloc(1, HESS_ERROR_SSE);
     pt->set = FALSE;
 
     PROTECT(ptr = R_MakeExternalPtr(pt, R_NilValue, R_NilValue));
@@ -149,27 +149,27 @@ void hess_error_set(SEXP env) {
     SEXP y, x, wy, WX;
     int i, n, p, np, pc=0;
 
-    n = INTEGER_POINTER(findVarInFrame(env, install("n")))[0];
-    p = INTEGER_POINTER(findVarInFrame(env, install("p")))[0];
+    n = INTEGER_POINTER(Rf_findVarInFrame(env, Rf_install("n")))[0];
+    p = INTEGER_POINTER(Rf_findVarInFrame(env, Rf_install("p")))[0];
     np = n*p;
 
-    pt = (HESS_ERROR_SSE *) R_ExternalPtrAddr(findVarInFrame(env,
-        install("ptr")));
-    if (pt->set) error("hess_error_set: function called out of order");
+    pt = (HESS_ERROR_SSE *) R_ExternalPtrAddr(Rf_findVarInFrame(env,
+        Rf_install("ptr")));
+    if (pt->set) Rf_error("hess_error_set: function called out of order");
 
-    PROTECT(y = findVarInFrame(env, install("y"))); pc++;
-    PROTECT(x = findVarInFrame(env, install("x"))); pc++;
-    PROTECT(wy = findVarInFrame(env, install("wy"))); pc++;
-    PROTECT(WX = findVarInFrame(env, install("WX"))); pc++;
+    PROTECT(y = Rf_findVarInFrame(env, Rf_install("y"))); pc++;
+    PROTECT(x = Rf_findVarInFrame(env, Rf_install("x"))); pc++;
+    PROTECT(wy = Rf_findVarInFrame(env, Rf_install("wy"))); pc++;
+    PROTECT(WX = Rf_findVarInFrame(env, Rf_install("WX"))); pc++;
 
-    pt->y = Calloc(n, double);
-    pt->x = Calloc(np, double);
-    pt->yl = Calloc(n, double);
-    pt->wy1 = Calloc(n, double);
-    pt->xl = Calloc(np, double);
-    pt->wx1 = Calloc(np, double);
-    pt->beta1 = Calloc(p, double);
-    pt->xlb = Calloc(n, double);
+    pt->y = R_Calloc(n, double);
+    pt->x = R_Calloc(np, double);
+    pt->yl = R_Calloc(n, double);
+    pt->wy1 = R_Calloc(n, double);
+    pt->xl = R_Calloc(np, double);
+    pt->wx1 = R_Calloc(np, double);
+    pt->beta1 = R_Calloc(p, double);
+    pt->xlb = R_Calloc(n, double);
 
     for (i=0; i<n; i++) {
         pt->y[i] = NUMERIC_POINTER(y)[i];
@@ -192,16 +192,16 @@ SEXP hess_error_free(SEXP ptr) {
 
     pt = (HESS_ERROR_SSE *) R_ExternalPtrAddr(ptr);
 
-    Free(pt->xlb);
-    Free(pt->beta1);
-    Free(pt->wx1);
-    Free(pt->xl);
-    Free(pt->wy1);
-    Free(pt->yl);
-    Free(pt->x);
-    Free(pt->y);
+    R_Free(pt->xlb);
+    R_Free(pt->beta1);
+    R_Free(pt->wx1);
+    R_Free(pt->xl);
+    R_Free(pt->wy1);
+    R_Free(pt->yl);
+    R_Free(pt->x);
+    R_Free(pt->y);
 
-    Free(pt);
+    R_Free(pt);
     R_ClearExternalPtr(ptr);
     return(R_NilValue);
 }
@@ -211,7 +211,7 @@ SEXP hess_lag_init(void) { /* -Wstrict-prototypes */
     HESS_LAG_SSE *pt;
     SEXP ptr;
 
-    pt = Calloc(1, HESS_LAG_SSE);
+    pt = R_Calloc(1, HESS_LAG_SSE);
     pt->set = FALSE;
 
     PROTECT(ptr = R_MakeExternalPtr(pt, R_NilValue, R_NilValue));
@@ -228,24 +228,24 @@ void hess_lag_set(SEXP env) {
     SEXP y, x, wy;
     int i, n, p, np, pc=0;
 
-    n = INTEGER_POINTER(findVarInFrame(env, install("n")))[0];
-    p = INTEGER_POINTER(findVarInFrame(env, install("m")))[0];
+    n = INTEGER_POINTER(Rf_findVarInFrame(env, Rf_install("n")))[0];
+    p = INTEGER_POINTER(Rf_findVarInFrame(env, Rf_install("m")))[0];
     np = n*p;
 
-    pt = (HESS_LAG_SSE *) R_ExternalPtrAddr(findVarInFrame(env,
-        install("ptr")));
-    if (pt->set) error("hess_lag_set: function called out of order");
+    pt = (HESS_LAG_SSE *) R_ExternalPtrAddr(Rf_findVarInFrame(env,
+        Rf_install("ptr")));
+    if (pt->set) Rf_error("hess_lag_set: function called out of order");
 
-    PROTECT(y = findVarInFrame(env, install("y"))); pc++;
-    PROTECT(x = findVarInFrame(env, install("x"))); pc++;
-    PROTECT(wy = findVarInFrame(env, install("wy"))); pc++;
+    PROTECT(y = Rf_findVarInFrame(env, Rf_install("y"))); pc++;
+    PROTECT(x = Rf_findVarInFrame(env, Rf_install("x"))); pc++;
+    PROTECT(wy = Rf_findVarInFrame(env, Rf_install("wy"))); pc++;
 
-    pt->y = Calloc(n, double);
-    pt->x = Calloc(np, double);
-    pt->yl = Calloc(n, double);
-    pt->wy1 = Calloc(n, double);
-    pt->beta1 = Calloc(p, double);
-    pt->xb = Calloc(n, double);
+    pt->y = R_Calloc(n, double);
+    pt->x = R_Calloc(np, double);
+    pt->yl = R_Calloc(n, double);
+    pt->wy1 = R_Calloc(n, double);
+    pt->beta1 = R_Calloc(p, double);
+    pt->xb = R_Calloc(n, double);
 
     for (i=0; i<n; i++) {
         pt->y[i] = NUMERIC_POINTER(y)[i];
@@ -265,14 +265,14 @@ SEXP hess_lag_free(SEXP ptr) {
 
     pt = (HESS_LAG_SSE *) R_ExternalPtrAddr(ptr);
 
-    Free(pt->xb);
-    Free(pt->beta1);
-    Free(pt->wy1);
-    Free(pt->yl);
-    Free(pt->x);
-    Free(pt->y);
+    R_Free(pt->xb);
+    R_Free(pt->beta1);
+    R_Free(pt->wy1);
+    R_Free(pt->yl);
+    R_Free(pt->x);
+    R_Free(pt->y);
 
-    Free(pt);
+    R_Free(pt);
     R_ClearExternalPtr(ptr);
     return(R_NilValue);
 }
@@ -299,16 +299,16 @@ SEXP R_ml_sse_env(SEXP env, SEXP coef) {
   int pc=0, first_time;
   OPT_ERROR_SSE *pt;
 
-  first_time = LOGICAL_POINTER(findVarInFrame(env, install("first_time")))[0];
+  first_time = LOGICAL_POINTER(Rf_findVarInFrame(env, Rf_install("first_time")))[0];
   if (first_time) {
     opt_error_set(env);
   }
 
-  n = INTEGER_POINTER(findVarInFrame(env, install("n")))[0];
-  p = INTEGER_POINTER(findVarInFrame(env, install("p")))[0];
+  n = INTEGER_POINTER(Rf_findVarInFrame(env, Rf_install("n")))[0];
+  p = INTEGER_POINTER(Rf_findVarInFrame(env, Rf_install("p")))[0];
   np = n*p;
-  pt = (OPT_ERROR_SSE *) R_ExternalPtrAddr(findVarInFrame(env,
-        install("ptr")));
+  pt = (OPT_ERROR_SSE *) R_ExternalPtrAddr(Rf_findVarInFrame(env,
+        Rf_install("ptr")));
 
   for (i=0; i<n; i++) pt->yl[i] = pt->y[i];
   for (i=0; i<np; i++) pt->xlq[i] = pt->x[i];
@@ -319,7 +319,7 @@ SEXP R_ml_sse_env(SEXP env, SEXP coef) {
 
   F77_CALL(dqrdc2)(pt->xlq, &n, &n, &p, &tol, &k, pt->qraux, pt->jpvt,
     pt->work); 
-  if (p != k) warning("Q looses full rank"); 
+  if (p != k) Rf_warning("Q looses full rank"); 
 /*  k = 0;
   F77_CALL(dqrdc)(pt->xlq, &n, &n, &p, pt->qraux, pt->jpvt, pt->work, &k);*/
 
@@ -356,16 +356,16 @@ SEXP R_ml1_sse_env(SEXP env, SEXP lambda, SEXP beta) {
   int pc=0, first_time;
   HESS_ERROR_SSE *pt;
 
-  first_time = LOGICAL_POINTER(findVarInFrame(env, install("first_time")))[0];
+  first_time = LOGICAL_POINTER(Rf_findVarInFrame(env, Rf_install("first_time")))[0];
   if (first_time) {
     hess_error_set(env);
   }
 
-  n = INTEGER_POINTER(findVarInFrame(env, install("n")))[0];
-  p = INTEGER_POINTER(findVarInFrame(env, install("p")))[0];
+  n = INTEGER_POINTER(Rf_findVarInFrame(env, Rf_install("n")))[0];
+  p = INTEGER_POINTER(Rf_findVarInFrame(env, Rf_install("p")))[0];
   np = n*p;
-  pt = (HESS_ERROR_SSE *) R_ExternalPtrAddr(findVarInFrame(env,
-        install("ptr")));
+  pt = (HESS_ERROR_SSE *) R_ExternalPtrAddr(Rf_findVarInFrame(env,
+        Rf_install("ptr")));
 
   for (i=0; i<n; i++) pt->yl[i] = pt->y[i];
   for (i=0; i<np; i++) pt->xl[i] = pt->x[i];
@@ -402,15 +402,15 @@ SEXP R_ml2_sse_env(SEXP env, SEXP rho, SEXP beta) {
   int pc=0, first_time;
   HESS_LAG_SSE *pt;
 
-  first_time = LOGICAL_POINTER(findVarInFrame(env, install("first_time")))[0];
+  first_time = LOGICAL_POINTER(Rf_findVarInFrame(env, Rf_install("first_time")))[0];
   if (first_time) {
     hess_lag_set(env);
   }
 
-  n = INTEGER_POINTER(findVarInFrame(env, install("n")))[0];
-  p = INTEGER_POINTER(findVarInFrame(env, install("m")))[0];
-  pt = (HESS_LAG_SSE *) R_ExternalPtrAddr(findVarInFrame(env,
-        install("ptr")));
+  n = INTEGER_POINTER(Rf_findVarInFrame(env, Rf_install("n")))[0];
+  p = INTEGER_POINTER(Rf_findVarInFrame(env, Rf_install("m")))[0];
+  pt = (HESS_LAG_SSE *) R_ExternalPtrAddr(Rf_findVarInFrame(env,
+        Rf_install("ptr")));
 
   for (i=0; i<n; i++) pt->yl[i] = pt->y[i];
   for (i=0; i<p; i++) pt->beta1[i] = NUMERIC_POINTER(beta)[i];
